@@ -1,3 +1,15 @@
+/*
+ *  Copyright (c) 2004-2023 by Jakob Schröter <js@camaya.net>
+ *  This file is part of the gloox library. http://camaya.net/gloox
+ *
+ *  This software is distributed under a license. The full license
+ *  agreement can be found in the file LICENSE in this distribution.
+ *  This software may not be copied, modified, sold or distributed
+ *  other than expressed in the named license agreement.
+ *
+ *  This software is distributed without any warranty.
+ */
+
 #include "../../tag.h"
 using namespace gloox;
 
@@ -27,7 +39,7 @@ void printResult( const std::string& name, ConstTagList& result )
 //   if( !t || t->toString() != name )
 //   {
 //     ++fail;
-//     printf( "test 'lexer: %s' failed: %s\n", name.c_str(), t->toString().c_str() );
+//     fprintf( stderr, "test 'lexer: %s' failed: %s\n", name.c_str(), t->toString().c_str() );
 //   }
 //   printf( "str: %s\n", t->toString().c_str() );
 //   printf( "xml: %s\n", t->xml().c_str() );
@@ -77,7 +89,7 @@ int main( int /*argc*/, char** /*argv*/ )
 //   if( t != 0 )
 //   {
 //     ++fail;
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   delete t;
 
@@ -87,7 +99,7 @@ int main( int /*argc*/, char** /*argv*/ )
 //   if( t != 0 )
 //   {
 //     ++fail;
-//     printf( "test 'lexer: %s' failed\n", name.c_str() );
+//     fprintf( stderr, "test 'lexer: %s' failed\n", name.c_str() );
 //   }
 //   delete t;
 
@@ -177,7 +189,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -185,7 +197,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "//" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -193,7 +205,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -201,7 +213,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -209,7 +221,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/aaa/bbb" ) != bbb )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -217,7 +229,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/aaa/ccc" ) != ccc )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -225,7 +237,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/aaa/ccc/ddd" ) != ddd )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -233,7 +245,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "//aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -241,7 +253,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "//eee" ) != eee )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -249,7 +261,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "//bbb" ) != bbb )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -257,7 +269,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( bbb->findTag( "/aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -265,7 +277,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/abc" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -273,7 +285,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "/bbb" ) != 0 )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -281,7 +293,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( aaa->findTag( "aaa" ) != aaa )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -289,7 +301,7 @@ int main( int /*argc*/, char** /*argv*/ )
   if( bbb->findTag( "bbb" ) != bbb )
   {
     ++fail;
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -300,7 +312,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -311,7 +323,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -324,7 +336,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -334,7 +346,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -345,7 +357,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -357,7 +369,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -367,7 +379,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -377,7 +389,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -387,7 +399,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -397,7 +409,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -408,7 +420,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -419,7 +431,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -430,7 +442,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -441,7 +453,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -452,7 +464,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -463,7 +475,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
 //   printf( "--------------------------------------------------------------\n" );
@@ -476,7 +488,7 @@ int main( int /*argc*/, char** /*argv*/ )
 //   {
 //     ++fail;
 //     printResult( name, result );
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -488,7 +500,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -499,7 +511,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -510,7 +522,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -523,7 +535,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   // -------
@@ -534,7 +546,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -553,7 +565,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -565,7 +577,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -577,7 +589,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -589,7 +601,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -602,7 +614,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -614,7 +626,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -635,7 +647,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -647,7 +659,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -659,7 +671,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -671,7 +683,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -683,7 +695,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -695,7 +707,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -707,7 +719,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -719,7 +731,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -731,7 +743,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -743,7 +755,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -755,7 +767,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 
   name = "deepsearch + predicate + literal 2: //bbb[@name='test@test2']";
@@ -766,7 +778,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -778,7 +790,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -790,7 +802,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -801,7 +813,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -813,7 +825,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -824,7 +836,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -836,7 +848,7 @@ int main( int /*argc*/, char** /*argv*/ )
 //   {
 //     ++fail;
 //     printResult( name, result );
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -848,7 +860,7 @@ int main( int /*argc*/, char** /*argv*/ )
 //   {
 //     ++fail;
 //     printResult( name, result );
-//     printf( "test '%s' failed\n", name.c_str() );
+//     fprintf( stderr, "test '%s' failed\n", name.c_str() );
 //   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -863,7 +875,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -872,7 +884,7 @@ int main( int /*argc*/, char** /*argv*/ )
   {
     ++fail;
     printResult( name, result );
-    printf( "test '%s' failed\n", name.c_str() );
+    fprintf( stderr, "test '%s' failed\n", name.c_str() );
   }
 //   printf( "--------------------------------------------------------------\n" );
 
@@ -935,7 +947,7 @@ int main( int /*argc*/, char** /*argv*/ )
   }
   else
   {
-    printf( "XPath: %d test(s) failed\n", fail );
+    fprintf( stderr, "XPath: %d test(s) failed\n", fail );
     return 1;
   }
 
